#include "12F629.h"  // device dependent definitions

/*****************
 * Drehgeber in Up-/Down-Signal umwandeln
 * Version mit Low-aktiven Ausgngen
 * Fr die Eingnge sind interne Pullups aktiviert, 
 * die ext. Beschaltung also sehr gering
 *****************/

//Zeit in ms, die zwischen den  
#define OUT_PAUSE 20
//Hier eintragen, welcher Pegel wann auftreten soll
//Der "Standard-Pegel" (Ruhezustand) ist in LEVEL_LOW
#define LEVEL_HIGH 0
#define LEVEL_LOW 1

/*********************************************************/
/****** Ab hier im Zweifelsfall nichts mehr ndern! ******/
/*********************************************************/


#pragma config |= 0b.0001.1010.0100
//                   xxx| |||| |^^^Taktgeber INTOSC
//                      | |||| +Watchdog
//                      | |||+Power up Timer off
//                      | ||+GP5=MCLR
//                      | |+Brown Out Reset
//                      | +CodeProtect aus
//											+EEPromProtect aus

#include <common.c>

void main() {
	OPTION=0b.1100.0001; //Pullups an, Prescaler auf TMR0, 1:4
	CMCON=0x07; //kein Komperator
	//ANSEL=0x00; //alles digitale IO-Pins (einkommentieren, wenn es ein 12F675 ist)
	WPU=0b.0000.0011; //ein paar Pullups an GPIO an
	
	TRISIO = 0b.0000.0011;  //0 = Output, 1 = Input
  unsigned int drehpos = 0; //Variablen fr den Drehgeber initialisieren
  unsigned int lstdrehpos = 0;
	
	GPIO.4 = LEVEL_LOW; //Standardzustand der Ausgnge festlegen
	GPIO.5 = LEVEL_LOW;
	
	while(1) {
		drehpos = GPIO.0; 
		if(GPIO.1) drehpos ^=3; //^= toggelt mit der entsprechenden Zahl
		
		if (((drehpos - lstdrehpos) == 1) || 
				((lstdrehpos - drehpos) == 3)) {
			GPIO.4 = LEVEL_HIGH;
			wait(OUT_PAUSE);
			GPIO.4 = LEVEL_LOW;
		} else if (((lstdrehpos - drehpos) == 1) || 
							 ((drehpos - lstdrehpos) == 3)) {
			GPIO.5 = LEVEL_HIGH;
			wait(OUT_PAUSE);
			GPIO.5 = LEVEL_LOW;
		}
		lstdrehpos = drehpos;
	}
}
